Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(288)

Unified Diff: lib/core/embedded_core.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/core/double.dart ('k') | lib/core/embedded_core_patch.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/core/embedded_core.dart
diff --git a/lib/core/embedded_core.dart b/lib/core/embedded_core.dart
index d62ee725903243ffa1ed17e6de09f15faafe4ee1..14a58878d58d814fc93b07d714145c96dbd0c719 100644
--- a/lib/core/embedded_core.dart
+++ b/lib/core/embedded_core.dart
@@ -2,11 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
/// The dart:core library for embedded fletch.
///
/// It is imported by default in all libraries.
///
/// It is the same as the mobile fletch core library without the
/// Regexp and Uri classes.
library dart.core;
@@ -35,9 +35,9 @@ import "dart:math" show Random; // Used by List.shuffle
import "dart:_internal" as internal show Symbol;
// TODO(sigurdm): Make fletchc not depend on seeing this library. It is
// currently hard-coded to look for [ForeignMemory].
-import 'dart:fletch.ffi' as not_needed; // Needed by fletchc.
+import 'dart:dartino.ffi' as not_needed; // Needed by dartino_compiler.
part "dart:_core_annotations";
part "dart:_core_bool";
« no previous file with comments | « lib/core/double.dart ('k') | lib/core/embedded_core_patch.dart » ('j') | no next file with comments »
@@ -2,11 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-/// The dart:core library for embedded fletch.
+/// The dart:core library for embedded dartino.
///
/// It is imported by default in all libraries.
@@ -2,11 +2,11 @@
/// It is imported by default in all libraries.
///
-/// It is the same as the mobile fletch core library without the
+/// It is the same as the mobile dartino core library without the
/// Regexp and Uri classes.
library dart.core;
@@ -35,9 +35,9 @@ import "dart:math" show Random; // Used by List.shuffle
import "dart:_internal" as internal show Symbol;
-// TODO(sigurdm): Make fletchc not depend on seeing this library. It is
+// TODO(sigurdm): Make dartino_compiler not depend on seeing this library. It is
// currently hard-coded to look for [ForeignMemory].

Powered by Google App Engine
This is Rietveld 408576698